@@ -1,11 +1,12 @@
 """Map event module."""
 from dataclasses import dataclass
-from enum import Enum
-from typing import List
+from enum import Enum, unique
+from typing import Any, Optional
 
 from ..events import Event
 
 
+@unique
 class PositionType(str, Enum):
     """Position type enum."""
 
@@ -26,7 +27,7 @@ class Position:
 class PositionsEvent(Event):
     """Position event representation."""
 
-    positions: List[Position]
+    positions: list[Position]
 
 
 @dataclass(frozen=True)
@@ -44,14 +45,7 @@ class MajorMapEvent(Event):
 
     requested: bool
     map_id: str
-    values: List[str]
-
-
-@dataclass(frozen=True)
-class MapSetEvent(Event):
-    """Map set event."""
-
-    rooms_count: int
+    values: list[str]
 
 
 @dataclass(frozen=True)
@@ -60,3 +54,36 @@ class MinorMapEvent(Event):
 
     index: int
     value: str
+
+
+@unique
+class MapSetType(str, Enum):
+    """Map set type enum."""
+
+    ROOMS = "ar"
+    VIRTUAL_WALLS = "vw"
+    NO_MOP_ZONES = "mw"
+
+    @classmethod
+    def has_value(cls, value: Any) -> bool:
+        """Check if value exists."""
+
+        return value in cls._value2member_map_  # pylint: disable=no-member
+
+
+@dataclass(frozen=True)
+class MapSetEvent(Event):
+    """Map set event."""
+
+    type: MapSetType
+    subsets: list[int]
+
+
+@dataclass(frozen=True)
+class MapSubsetEvent(Event):
+    """Map subset event."""
+
+    id: int
+    type: MapSetType
+    coordinates: str
+    subtype: Optional[str] = None
